'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

var useFPSCore = function useFPSCore(_ref) {
  var _ref$fpsHistory = _ref.fpsHistory,
      fpsHistory = _ref$fpsHistory === void 0 ? 70 : _ref$fpsHistory,
      _ref$fpsSampleRate = _ref.fpsSampleRate,
      fpsSampleRate = _ref$fpsSampleRate === void 0 ? 1000 : _ref$fpsSampleRate;
  var fpsCorection = 1000 / fpsSampleRate;

  var _useState = React.useState(0),
      frames = _useState[0],
      _setFrames = _useState[1];

  var framesRef = React.useRef(frames);

  var setFrames = function setFrames(data) {
    framesRef.current = data;

    _setFrames(data);
  };

  var prevTimeRef = React.useRef(+new Date());

  var setPrevTime = function setPrevTime(data) {
    prevTimeRef.current = data;
  };

  var _useState2 = React.useState([]),
      fps = _useState2[0],
      _setFps = _useState2[1];

  var fpsRef = React.useRef(fps);

  var setFps = function setFps(data) {
    fpsRef.current = data;

    _setFps(data);
  };

  React.useEffect(function () {
    var afRequest;

    var onRequestAnimationFrame = function onRequestAnimationFrame() {
      calcFPS();
      afRequest = window.requestAnimationFrame(onRequestAnimationFrame);
    };

    afRequest = window.requestAnimationFrame(onRequestAnimationFrame);
    return function () {
      window.cancelAnimationFrame(afRequest);
    };
  }, []);

  var calcFPS = function calcFPS() {
    var currentTime = +new Date();

    var _frames = framesRef.current + 1;

    setFrames(_frames);

    if (currentTime > prevTimeRef.current + fpsSampleRate) {
      var _fps = Math.round(_frames * fpsSampleRate / (currentTime - prevTimeRef.current) * fpsCorection);

      var sliceStart = Math.min(fpsRef.current.length - fpsHistory, 0);
      setPrevTime(+new Date());
      setFps([].concat(fpsRef.current.slice(sliceStart - 1, fpsRef.current.length), [_fps]));
      setFrames(0);
    }
  };

  return {
    frames: frames,
    fps: fps
  };
};

var useFPSDetect = function useFPSDetect(_ref) {
  var _ref$minimumFps = _ref.minimumFps,
      minimumFps = _ref$minimumFps === void 0 ? 20 : _ref$minimumFps,
      _ref$fpsSampleRate = _ref.fpsSampleRate,
      fpsSampleRate = _ref$fpsSampleRate === void 0 ? 1000 : _ref$fpsSampleRate,
      _ref$fpsHistory = _ref.fpsHistory,
      fpsHistory = _ref$fpsHistory === void 0 ? 2 : _ref$fpsHistory;

  var _useFPSCore = useFPSCore({
    fpsHistory: fpsHistory,
    fpsSampleRate: fpsSampleRate
  }),
      fps = _useFPSCore.fps;

  var _useState = React.useState(false),
      lowFrameRate = _useState[0],
      setLowFrameRate = _useState[1];

  React.useEffect(function () {
    var average = function average(array) {
      return array.reduce(function (a, b) {
        return a + b;
      }, 0) / array.length;
    };

    average(fps) <= minimumFps && setLowFrameRate(true);
  }, [fps]);
  return lowFrameRate;
};

var fpsHistory = 50;
var FPSStats = function FPSStats(_ref) {
  var _ref$top = _ref.top,
      top = _ref$top === void 0 ? 2 : _ref$top,
      _ref$left = _ref.left,
      left = _ref$left === void 0 ? 2 : _ref$left,
      _ref$bottom = _ref.bottom,
      bottom = _ref$bottom === void 0 ? 'auto' : _ref$bottom,
      _ref$right = _ref.right,
      right = _ref$right === void 0 ? 'auto' : _ref$right,
      _ref$fpsSampleRate = _ref.fpsSampleRate,
      fpsSampleRate = _ref$fpsSampleRate === void 0 ? 1000 : _ref$fpsSampleRate;

  var _useFPSCore = useFPSCore({
    fpsHistory: fpsHistory,
    fpsSampleRate: fpsSampleRate
  }),
      fps = _useFPSCore.fps;

  var wrapperStyle = {
    zIndex: 999999,
    position: 'fixed',
    height: '50px',
    width: '75px',
    padding: '3px',
    backgroundColor: 'rgba(52, 52, 52, 0.8)',
    borderRadius: '4px',
    color: '#ebebeb ',
    fontSize: '9px',
    fontFamily: 'Helvetica, Arial, sans-serif',
    textAlign: 'center',
    top: top,
    right: right,
    bottom: bottom,
    left: left
  };
  var fpsStatsStyle = {
    width: '73px',
    position: 'absolute',
    left: 0,
    bottom: 0,
    padding: '4px'
  };
  var width = fpsHistory * 10;
  return React__default.createElement("div", {
    style: wrapperStyle
  }, React__default.createElement("span", null, fps[fps.length - 1], " FPS"), React__default.createElement("svg", {
    viewBox: "0 0 " + width + " 250",
    style: fpsStatsStyle
  }, React__default.createElement("polyline", {
    id: "pol",
    fill: "#fff",
    stroke: "#fff",
    points: '0 250,' + fps.slice().reverse().map(function (fps, i) {
      return i * 20 + " " + (250 - fps * (250 / 60));
    }).join('\r\n') + ("," + (fps.length - 1) * 20 + " 250")
  })));
};

exports.FPSStats = FPSStats;
exports.useFPSCore = useFPSCore;
exports.useFPSDetect = useFPSDetect;
//# sourceMappingURL=fps-react.cjs.development.js.map
